/*
** Module   : RadioSetWidget.java
** Abstract : server side radioset widget implementation
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 NVS 20051026   @23494 Created initial version.
** 002 SIY 20050209   @24428 Major refactoring.
** 003 GES 20060803   @28382 Some cleanup and refactoring.
** 004 GES 20080320   @37593 Added TYPE attribute.
** 018 SIY 20111101          Updated imports.
** 019 CA  20130221          Refactored usage of TYPE attribute.
** 020 CA  20130222          Added NPE protection for cases when a widget is used before is 
**                           attached to a frame (after a CREATE WIDGET statement is used).
** 021 CA  20130927          Added LegacyResource annotation, to determine resource type.
** 022 CA  20131115          Changes related to properly instantiate dynamic resources.
*/ 

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Server side radioset widget implementation.
 */
@LegacyResource(resource = LegacyResource.RADIO_SET)
public class RadioSetWidget
extends ControlSetEntity
{
   /** Reference to our configuration which is pre-cast to the proper type. */
   private RadioSetConfig rsc = null;
   
   /**
    * Default constructor.
    */
   public RadioSetWidget()
   {
      this(false);
   }
   
   /**
    * Default constructor.
    * 
    * @param    dynamic
    *           Flag indicating if this is a static or dynamic resource.
    */
   public RadioSetWidget(boolean dynamic)
   {
      super(dynamic, new RadioSetConfig(ComponentConfig.RADIO_SET, null));
      rsc = (RadioSetConfig) config;
   }

   /**
    * Resets the value of the HORIZONTAL attribute for radio-set.
    * 
    * @param   horizontal
    *          The new value of the HORIZONTAL attribute.
    */
   public void setHorizontal(boolean horizontal)
   {
      rsc.setHorizontal(horizontal);
      pushScreenDefinition();
   }

   /**
    * Resets the value of the HORIZONTAL attribute for radio-set.
    * 
    * @param   horizontal
    *          The new value of the HORIZONTAL attribute.
    */
   public void setHorizontal(logical horizontal)
   {
      setHorizontal(horizontal.booleanValue());
   }
   
   /**
    * Get RADIO-BUTTONS attribute.
    * 
    * @return  Current value of the attribute.
    */
   public character getRadioButtons()
   {
      return getListItemPairs();
   }
   
   /**
    * Set RADIO-BUTTONS attribute. The parameter contains string
    * representation of all radio button labels and values separated by
    * delimiter (comma is the default value).
    * <p>
    * Example: <code>Label1,value1,Label2,value2,..., LabelN,valueN</code>
    * 
    * @param   c
    *          New value of the attribute.
    */
   public void setRadioButtons(character c)
   {
      setListItemPairs(c);
   }
}
