/*
** Module   : SkipEntity.java
** Abstract : server side skip and space pseudo-widgets
**
** Copyright (c) 2005-2011, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 NVS 20051026   @23496 Created initial version.
** 002 SIY 20060316   @25140 Additional constructor.
** 003 GES 20060803   @28384 Some cleanup and refactoring.
** 004 SIY 20060805   @28446 Added required SkipEntity(int) constructor.
** 005 GES 20061101   @30862 Allow decimal values for skip and space
**                           sizes (and properly round them).
** 006 SIY 20070706   @34396 Fixed setWidth().
** 007 NVS 20070706   @34398 setWidth(double) should round up, not ceil()
**                           nor floor() the parameter. Confirmed with 
**                           skip-round.p testcase
** 008 SIY 20111101          Updated imports.
** 009 CA  20130930          Added LegacyResource annotation, to determine resource type.
** 010 CA  20131115          Changes related to properly instantiate dynamic resources.
*/ 

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Implements the server side skip and space pseudo-widgets.
 */
@LegacyResource(resource = LegacyResource.SKIP_OR_SPACE)
public class SkipEntity
extends GenericWidget
{
   /** Reference to our configuration which is pre-cast to the proper type. */
   private SkipConfig skip = null;
   
   /**
    * Default constructor (creates a space, not a skip).
    */
   public SkipEntity()
   {
      super(false, new SkipConfig(ComponentConfig.SKIP, null));
      skip = (SkipConfig) config; 
   }

   /**
    * Construct SPACE or SKIP depending on the argument.
    * 
    * @param   vertical
    *          If <code>true</code> then SKIP is created, otherwise created
    *          SPACE.
    */
   public SkipEntity(boolean vertical)
   {
      this();
      skip.setVertical(vertical);
   }

   /**
    * Create an instance of SKIP with specified size.
    * 
    * @param   size
    *          The number of line feeds.
    */
   public SkipEntity(int size)
   {
      this(true);
      skip.setHeight(size);
   }

   /**
    * Gets the number of line feeds.
    *
    * @return   The number of line feeds to insert (0 if this represents a
    *           space instead of a skip).
    */
    public int getSkip()
    {
       return skip.getHeight();
    }
    
   /**
    * Sets the type of the widget (skip or space).
    *
    * @param    vertical
    *           <code>true</code> for skip, <code>false</code> for space.
    */
    public void setVertical(boolean vertical)
    {
       skip.setVertical(vertical);
    }

   /**
    * Sets the width of the space or skip object. It is equal to the number of
    * skipped columns for space object. Operation is ignored for the skip
    * object.
    * 
    * @param    width
    *           The width of the object.
    */
   public void setWidth(double width)
   {
      skip.setWidth((int) Math.round(width));
   }
   
   /**
    * Sets the height of the space or skip object. It is equal to the number
    * of skipped rows for skip object. Operation is ignored for the space
    * object.
    * 
    * @param    height
    *           The height of the skip object.
    */
   public void setHeight(double height)
   {
      // Progress seems to round down to the nearest integral value
      skip.setHeight((int) height);
   }
   
   /**
    * Get the VISIBLE writable attribute.
    *
    * @return   The current value of VISIBLE attribute.
    */
   public logical isVisible()
   {
      throw new RuntimeException("VISIBLE attribute is undefined");
   }

   /**
    * Set the VISIBLE writable attribute.
    *
    * @param    visible
    *           The new value for the VISIBLE attribute.
    */
   public void setVisible(logical visible)
   {
      throw new RuntimeException("VISIBLE attribute is undefined");
   }

   /**
    * Set the VISIBLE writable attribute.
    *
    * @param    visible
    *           The new value for the VISIBLE attribute.
    */
   public void setVisible(boolean visible)
   {
      throw new RuntimeException("VISIBLE attribute is undefined");
   }   
}
